/***************************************************************************

	TITLE:		F3F.c
	
----------------------------------------------------------------------------

	FUNCTION:	routine for F3f race handling

----------------------------------------------------------------------------

	MODULE STATUS:	Developmental

----------------------------------------------------------------------------

	GENEALOGY:	Written 08 december 01

----------------------------------------------------------------------------

	DESIGNED BY:	OBR
	
	CODED BY:	OBR
	
	MAINTAINED BY:	OBR

----------------------------------------------------------------------------*/

#include <windows.h>
#include <stdlib.h>
#include <stdio.h>
#include <math.h>
#include <time.h>
#include "glut.h"


#include "ls_types.h"
#include "ls_constants.h"
#include "ls_geodesy.h"
#include "ls_generic.h"

#include "f3f.h"


char f3f_score [1024]="STARTING";
char f3f_time [256]="[Time: 0]";

#ifdef linux
	time_t time_30sec;			/* time at launch */
	time_t start_time;			/* time when the run is started */
	time_t runresult=0;
	time_t runcomplete=0;
	time_t runcurrent=0;
#endif
#ifdef WIN32
#include "MAPIWIN.H"
	SYSTEMTIME time_30sec;			/* time at launch */
	int start_time;			/* time when the run is started */
	int runresult=0;
	int runcomplete=0;
	int runcurrent=0;
#endif

int run_will_start = FALSE; 
int run_started = FALSE; 
int run_completed = FALSE;
int x1_toggle = FALSE;
int x2_toggle = FALSE;

int base_count =-1;
int cross_base =CROSS_RIGHT;
int in_penalty = TRUE;
int penality_count=0;
int start_from_ground = TRUE;

int elapsed_time[MAX_LAPS+1];



void restart_f3f()
{
    run_will_start = FALSE; 
	run_started = FALSE; 
	run_completed = FALSE;
	x1_toggle = FALSE;
	x2_toggle = FALSE;
	base_count =-1;
	cross_base =CROSS_RIGHT;
	in_penalty = TRUE;
	penality_count=0;
	runresult=0;
//	sprintf (f3f_score,"STARTING");

	/* reset time for 30 sec countdown */
#ifdef linux
	time(&time_30sec);
#endif
#ifdef WIN32
	GetSystemTime (&time_30sec);
#endif
//	printf ("start time %d\n",SYSTIMETOINT(time_30sec));
}

/*
	Purpose: Get Time when starting the run
*/
void run_start()
{
#ifdef linux
	time_t cur_time;
#endif
#ifdef WIN32
	SYSTEMTIME cur_time;
#endif

	if ((X_cg_rwy > PLANLIMIT) && (run_will_start == FALSE))  
		run_will_start = TRUE;  

	if ((X_cg_rwy < PLANLIMIT) && (run_will_start == TRUE) && (run_started == FALSE)) {
		run_started = TRUE;
		printf ("\007");
#ifdef linux
		time (&cur_time);
		/* check if 30 seconds time is exceeded */
		if (cur_time - time_30sec > MAX_START_TIME)
			start_time = cur_time - (cur_time - time_30sec -MAX_START_TIME);
		else
			start_time = cur_time;

		runresult= cur_time - start_time ;
#endif
#ifdef WIN32
		GetSystemTime (&cur_time);
		/* check if 30 seconds time is exceeded */
		if (SYSTIMETOINT(cur_time) - SYSTIMETOINT(time_30sec) > MAX_START_TIME)
			start_time = SYSTIMETOINT(cur_time) - (SYSTIMETOINT(cur_time) - SYSTIMETOINT(time_30sec) -MAX_START_TIME);
		else
			start_time = SYSTIMETOINT(cur_time);

		runresult= (SYSTIMETOINT(cur_time) - start_time );
#endif	
//		printf ("Run Start at %d %d %d %d\n", 	start_time, cur_time,time_30sec,runresult);
	
		UPDATE_SCORE;
	}
}

/* 
	check if the model cross pylons A or pylons B
	Increase BASE counter 
*/

void check_cross_base ()
{
#ifdef linux
	time_t cur_time;
#endif
#ifdef WIN32
	SYSTEMTIME cur_time;
#endif
	int i;

	run_start();

	if (Y_cg_rwy < 0) {
		if (in_penalty == FALSE) {
			in_penalty = TRUE;
//			printf ("Penalite: 100 points \n");
			penality_count++;
		}
	}
	else in_penalty = FALSE;

	if ((X_cg_rwy > PLANLIMIT) && (cross_base == CROSS_RIGHT)) { 
		cross_base = CROSS_LEFT;
		if (x1_toggle == FALSE) {
			x1_toggle = TRUE;
			printf ("\007");    //SET BELL TO 'C:\WINDOWS\DING.WAV'
			base_count++; 
//			printf ("BASE   %d\n",base_count);
			if (base_count > 0) {
#ifdef linux
				time (&cur_time);
				runresult=  (cur_time - start_time);
#endif
#ifdef WIN32
				GetSystemTime (&cur_time);
				runresult=  (SYSTIMETOINT(cur_time) - start_time);
#endif
			}
			UPDATE_SCORE;
			elapsed_time[base_count]= runresult;
	//		sprintf (wtitle,"BASE   %d",base_count);
	//		glutSetWindowTitle(wtitle);
	//		glutPostRedisplay();
			if (base_count == 10) { 
#ifdef linux
				time (&cur_time);
				runresult = cur_time - start_time;
#endif
#ifdef WIN32
				GetSystemTime (&cur_time);
				runresult=  (SYSTIMETOINT(cur_time) - start_time);
#endif
//				printf ("basse count %d\n",base_count);
//				printf ("================>  RUN: %ds\n", runresult);
				UPDATE_SCORE;
				for (i=1;i<=10;i++) {
					int itime;
					itime = elapsed_time[i]-elapsed_time[i-1];
					printf ("Base: %d, time: %d.%d\n",i, itime/1000, (itime%1000)/10);
				}
				runcomplete= runresult;
				run_completed = TRUE;

				/* save result in score file */
				{
					FILE *fp;
					char thetime [256];
					char thedate [256];
					char thestart [256];

					fp = fopen ("f3f_score.txt","a+");
					_strtime(thetime);
					_strdate(thedate);
					if (start_from_ground == TRUE)
						sprintf (thestart,"Start from ground");
					else
						sprintf (thestart,"Start from altitude");

					fprintf (fp,"%s, %s, Run: %2d.%2ds, penalty %d, %s\n", thedate, thetime, 
						runresult/1000,runresult%1000/10, penality_count,thestart);
					fclose (fp);
				}
//				run_will_start = FALSE; 
//				run_started = FALSE; 
//				run_completed = TRUE;
//				x1_toggle = FALSE;
//				x2_toggle = FALSE;
//				base_count = -1;
//				cross_base = CROSS_RIGHT;
//				time(&time_30sec);
			}
		}

	}
   else {
		x1_toggle = FALSE;
		if ((X_cg_rwy < -PLANLIMIT) && (cross_base == CROSS_LEFT)){ 
			cross_base = CROSS_RIGHT;
			if (x2_toggle == FALSE) {
				x2_toggle = TRUE;
				printf ("\007");    //SET BELL TO 'C:\WINDOWS\DING.WAV'

			base_count++;
				
#ifdef linux
				time (&cur_time);
				runresult = cur_time - start_time;
#endif
#ifdef WIN32
				GetSystemTime (&cur_time);
				runresult=  (SYSTIMETOINT(cur_time) - start_time);
#endif

				UPDATE_SCORE;
				elapsed_time[base_count]= runresult;
//				if (base_count == 10) { 
//					printf ("\007"); 
//				}
			}
		}
		else {
			x2_toggle = FALSE;
		}
   }
}




